Struct plaid::sandbox::CreateSandboxPublicTokenResponse[][src]

pub struct CreateSandboxPublicTokenResponse {
    pub request_id: String,
    pub public_token: String,
}

Fields

request_id: String

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

public_token: String

A public token that can be exchanged for an access token using /item/public_token/exchange